@@ -6,22 +6,22 @@ class Logger(object):
         try:
             self.logger.debug(message)
         except:
-            print "DEBUG: %s" % message
+            print("DEBUG: %s" % message)
 
     def info(self, message):
         try:
             self.logger.info(message)
         except:
-            print "INFO: %s" % message
+            print("INFO: %s" % message)
 
     def warning(self, message):
         try:
             self.logger.warning(message)
         except:
-            print "WARNING: %s" % message
+            print("WARNING: %s" % message)
 
     def error(self, message):
         try:
             self.logger.error(message)
         except:
-            print "ERROR: %s" % message
+            print("ERROR: %s" % message)
